import { Form } from "antd"
import { forwardRef, useEffect, useImperativeHandle, } from "react"
import { ProForm, ProFormSelect, ProFormText } from "@ant-design/pro-components"
import { useModel } from "@umijs/max"
import UploadImg from "@/components/uploadImg"


const MyForm = forwardRef((props: { index: any, arr: any[], appId: any, set: (v: any) => void }, ref) => {
    let { index, arr, appId, set } = props
    let { getEnum } = useModel("global")
    const [form] = Form.useForm();
    // 将子组件的 ref 暴露给父组件
    useImperativeHandle(ref, () => ({
       form
    }));
    useEffect(() => {
        console.log("arr[index]",arr[index])
        form?.setFieldsValue(arr[index])
    }, [arr])
    return <ProForm
        form={form}  // 绑定 form 实例
        layout="horizontal"
        submitter={false}
        labelCol={{ span: 3 }}
        onValuesChange={(changedValues: any, values: any) => {
            console.log("values",values)
            let newArrCopy: any = JSON.parse(JSON.stringify(arr));
            newArrCopy[index] = values
            set(newArrCopy)
        }}
    >
        <Form.Item noStyle shouldUpdate>
            {(form) => {
                return (
                    <ProFormSelect
                        options={getEnum("MEDIA_TYPE", "arr")}
                        width="md"
                        name="mediaType"
                        label={`消息类型`}
                        onChange={(value) => {
                            if (value === "miniprogram") {
                                form?.setFieldsValue({ "miniprogramAppid": appId, "miniprogramPage": "pages/index/index" })
                            }
                        }}
                        rules={[
                            {
                                required: true,
                                message: '此项为必填项',
                            }
                        ]}
                    />
                );
            }}
        </Form.Item>
        {/* 小程序卡片 */}
        <Form.Item noStyle shouldUpdate>
            {({ getFieldValue }) => {
                let mediaType = getFieldValue("mediaType")
                switch (mediaType) {
                    case "text":
                        return <>文本</>
                    case "link":
                        return <>图文</>
                    case "miniprogram":
                        return <div >
                            <ProFormText
                                label="标题"
                                name="miniprogramTitle"
                                rules={[
                                    {
                                        max: 21
                                    },
                                    {
                                        required: true,
                                        message: '此项为必填项',
                                    }
                                ]}
                            />
                            <ProFormText
                                label="路径"
                                name="miniprogramPage"
                                rules={[
                                    {
                                        required: true,
                                        message: '此项为必填项',
                                    }
                                ]}
                                fieldProps={{ placeholder: "pages/index/index" }}
                            />
                            <Form.Item label="图片" name="miniprogramPicurl" rules={[
                                {
                                    required: true,
                                    message: '此项为必填项',
                                }
                            ]}>
                                <UploadImg
                                    size={{
                                        width: 500,
                                        height: 400,
                                        evalW: '!=',
                                        evalH: '!=',
                                        msg: '需要图片大小690*248',
                                    }}
                                    isEdit={true}
                                    type="image"
                                    isCropper
                                />
                            </Form.Item>
                            <Form.Item hidden={true} >
                                <ProFormText
                                    label="小程序ID"
                                    name="miniprogramAppid"
                                    rules={[
                                        {
                                            max: 21
                                        },
                                        {
                                            required: true,
                                            message: '此项为必填项',
                                        }
                                    ]}
                                />
                            </Form.Item>
                            <Form.Item hidden={true} >
                                <ProFormText
                                    label="ID"
                                    name="id"
                                />
                            </Form.Item>
                        </div>
                }
            }}
        </Form.Item>
    </ProForm>
})

export default MyForm